==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/ScaleRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.ScaleRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Container App container scaling rule.
 * @property azureQueue Azure Queue based scaling.
 * @property custom Custom scale rule.
 * @property http HTTP requests based scaling.
 * @property name Scale Rule Name
 * @property tcp Tcp requests based scaling.
 */
public data class ScaleRuleArgs(
    public val azureQueue: Output<QueueScaleRuleArgs>? = null,
    public val custom: Output<CustomScaleRuleArgs>? = null,
    public val http: Output<HttpScaleRuleArgs>? = null,
    public val name: Output<String>? = null,
    public val tcp: Output<TcpScaleRuleArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.ScaleRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.ScaleRuleArgs =
        com.pulumi.azurenative.app.inputs.ScaleRuleArgs.builder()
            .azureQueue(azureQueue?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .custom(custom?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .http(http?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .tcp(tcp?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ScaleRuleArgs].
 */
@PulumiTagMarker
public class ScaleRuleArgsBuilder internal constructor() {
    private var azureQueue: Output<QueueScaleRuleArgs>? = null

    private var custom: Output<CustomScaleRuleArgs>? = null

    private var http: Output<HttpScaleRuleArgs>? = null

    private var name: Output<String>? = null

    private var tcp: Output<TcpScaleRuleArgs>? = null

    /**
     * @param value Azure Queue based scaling.
     */
    @JvmName("hjjnngfmdsdawgwf")
    public suspend fun azureQueue(`value`: Output<QueueScaleRuleArgs>) {
        this.azureQueue = value
    }

    /**
     * @param value Custom scale rule.
     */
    @JvmName("bqqclyxvbgwdyglv")
    public suspend fun custom(`value`: Output<CustomScaleRuleArgs>) {
        this.custom = value
    }

    /**
     * @param value HTTP requests based scaling.
     */
    @JvmName("jckmnbjkqlfnblrj")
    public suspend fun http(`value`: Output<HttpScaleRuleArgs>) {
        this.http = value
    }

    /**
     * @param value Scale Rule Name
     */
    @JvmName("xpvwliyhjhsbdusl")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Tcp requests based scaling.
     */
    @JvmName("jmptuywplkludwqp")
    public suspend fun tcp(`value`: Output<TcpScaleRuleArgs>) {
        this.tcp = value
    }

    /**
     * @param value Azure Queue based scaling.
     */
    @JvmName("fqpmexnwrrpijrrt")
    public suspend fun azureQueue(`value`: QueueScaleRuleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureQueue = mapped
    }

    /**
     * @param argument Azure Queue based scaling.
     */
    @JvmName("whxaynhofnguvreo")
    public suspend fun azureQueue(argument: suspend QueueScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = QueueScaleRuleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureQueue = mapped
    }

    /**
     * @param value Custom scale rule.
     */
    @JvmName("lperulmitmiwccvx")
    public suspend fun custom(`value`: CustomScaleRuleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.custom = mapped
    }

    /**
     * @param argument Custom scale rule.
     */
    @JvmName("kjpbjtitxpoeeeov")
    public suspend fun custom(argument: suspend CustomScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = CustomScaleRuleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.custom = mapped
    }

    /**
     * @param value HTTP requests based scaling.
     */
    @JvmName("uuscmmflxmpdokqm")
    public suspend fun http(`value`: HttpScaleRuleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.http = mapped
    }

    /**
     * @param argument HTTP requests based scaling.
     */
    @JvmName("dgaggpwqwokglafq")
    public suspend fun http(argument: suspend HttpScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = HttpScaleRuleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.http = mapped
    }

    /**
     * @param value Scale Rule Name
     */
    @JvmName("btvetdagalkylglw")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tcp requests based scaling.
     */
    @JvmName("esupswehgoyxvcio")
    public suspend fun tcp(`value`: TcpScaleRuleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tcp = mapped
    }

    /**
     * @param argument Tcp requests based scaling.
     */
    @JvmName("xkngujsdwlutnyxn")
    public suspend fun tcp(argument: suspend TcpScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = TcpScaleRuleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tcp = mapped
    }

    internal fun build(): ScaleRuleArgs = ScaleRuleArgs(
        azureQueue = azureQueue,
        custom = custom,
        http = http,
        name = name,
        tcp = tcp,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/ScaleRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.ScaleRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Container App container scaling rule.
 * @property azureQueue Azure Queue based scaling.
 * @property custom Custom scale rule.
 * @property http HTTP requests based scaling.
 * @property name Scale Rule Name
 * @property tcp Tcp requests based scaling.
 */
public data class ScaleRuleArgs(
    public val azureQueue: Output<QueueScaleRuleArgs>? = null,
    public val custom: Output<CustomScaleRuleArgs>? = null,
    public val http: Output<HttpScaleRuleArgs>? = null,
    public val name: Output<String>? = null,
    public val tcp: Output<TcpScaleRuleArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.ScaleRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.ScaleRuleArgs =
        com.pulumi.azurenative.app.inputs.ScaleRuleArgs.builder()
            .azureQueue(azureQueue?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .custom(custom?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .http(http?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .tcp(tcp?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ScaleRuleArgs].
 */
@PulumiTagMarker
public class ScaleRuleArgsBuilder internal constructor() {
    private var azureQueue: Output<QueueScaleRuleArgs>? = null

    private var custom: Output<CustomScaleRuleArgs>? = null

    private var http: Output<HttpScaleRuleArgs>? = null

    private var name: Output<String>? = null

    private var tcp: Output<TcpScaleRuleArgs>? = null

    /**
     * @param value Azure Queue based scaling.
     */
    @JvmName("jmmivduykhucvhfh")
    public suspend fun azureQueue(`value`: Output<QueueScaleRuleArgs>) {
        this.azureQueue = value
    }

    /**
     * @param value Custom scale rule.
     */
    @JvmName("segtolvvrvaoogdd")
    public suspend fun custom(`value`: Output<CustomScaleRuleArgs>) {
        this.custom = value
    }

    /**
     * @param value HTTP requests based scaling.
     */
    @JvmName("tqsabbmejgqjjvkp")
    public suspend fun http(`value`: Output<HttpScaleRuleArgs>) {
        this.http = value
    }

    /**
     * @param value Scale Rule Name
     */
    @JvmName("ouegqdtxfmpucpfj")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Tcp requests based scaling.
     */
    @JvmName("yputovocfqjnfnco")
    public suspend fun tcp(`value`: Output<TcpScaleRuleArgs>) {
        this.tcp = value
    }

    /**
     * @param value Azure Queue based scaling.
     */
    @JvmName("vgqmrufqrtmqmjuj")
    public suspend fun azureQueue(`value`: QueueScaleRuleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureQueue = mapped
    }

    /**
     * @param argument Azure Queue based scaling.
     */
    @JvmName("cbbptrsrodpkboxc")
    public suspend fun azureQueue(argument: suspend QueueScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = QueueScaleRuleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureQueue = mapped
    }

    /**
     * @param value Custom scale rule.
     */
    @JvmName("ugyxkcyqlfisjxis")
    public suspend fun custom(`value`: CustomScaleRuleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.custom = mapped
    }

    /**
     * @param argument Custom scale rule.
     */
    @JvmName("lelbfwpdrfbihlgt")
    public suspend fun custom(argument: suspend CustomScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = CustomScaleRuleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.custom = mapped
    }

    /**
     * @param value HTTP requests based scaling.
     */
    @JvmName("xohtwcahtpqgjugi")
    public suspend fun http(`value`: HttpScaleRuleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.http = mapped
    }

    /**
     * @param argument HTTP requests based scaling.
     */
    @JvmName("gfrpqydxyudbsoio")
    public suspend fun http(argument: suspend HttpScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = HttpScaleRuleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.http = mapped
    }

    /**
     * @param value Scale Rule Name
     */
    @JvmName("lycvibmxyyvqcbyt")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tcp requests based scaling.
     */
    @JvmName("okfcwlsetqahstmg")
    public suspend fun tcp(`value`: TcpScaleRuleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tcp = mapped
    }

    /**
     * @param argument Tcp requests based scaling.
     */
    @JvmName("ugldywphqabukhno")
    public suspend fun tcp(argument: suspend TcpScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = TcpScaleRuleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tcp = mapped
    }

    internal fun build(): ScaleRuleArgs = ScaleRuleArgs(
        azureQueue = azureQueue,
        custom = custom,
        http = http,
        name = name,
        tcp = tcp,
    )
}
